.. :changelog:

History
-------

1.1.0 (2018-01-11)
++++++++++++++++++
+ add pagination
+ add support for Django 2.x
+ drop support for Django 1.8 and Python 3.4
+ fix CI

1.0.1 (2016-03-30)
++++++++++++++++++
* refactored tests
* fixes heroku example app

1.0.0 (2016-03-26)
++++++++++++++++++

* removed urls.W002 (changed URL for list)
* changed URL format for reverse (introduced namespace)
* dropped support for python 2.x

0.1.0 (2015-05-09)
++++++++++++++++++

* First release on PyPI.
